<div id="table-specific">
<h4>About this table</h4>
{% block table_specific %}
<p class="explain">
Extend this template to maintain consistency.
Fill in this block with details specific to a table. 
Don't forget to use the 'explain' class on your &lt;p&gt; tags.
</p>
{% endblock %}
</div>
